Discover Packages
github.com/NWACus/expo-slack-webhook
api
submit
package
Version:
v0.0.0-...-420d421
Opens a new window with list of versions in this module.
Published: Apr 8, 2025
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Handle consumes the webhook and posts the data to Slack.
Handler is the entrypoint for Vercel serverless functions.
type Info struct {
Error expo .Error `json:"error"`
}
type WebhookPayload struct {
Id string `json:"id"`
Details string `json:"submissionDetailsPageUrl"`
Platform expo .Platform `json:"platform"`
Status expo .Status `json:"status"`
Info Info `json:"submissionInfo"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.