package
Version:
v0.0.0-...-420d421
Opens a new window with list of versions in this module.
Published: Apr 8, 2025
License: MIT
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Handle consumes the webhook and posts the data to Slack.
Handler is the entrypoint for Vercel serverless functions.
type Update struct {
Id string `json:"id"`
AppId string `json:"appId"`
Group string `json:"group"`
CreatedAt string `json:"createdAt"`
Branch string `json:"branch"`
Platform expo.Platform `json:"platform"`
GitCommitHash string `json:"gitCommitHash"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.